# Statische vs. Dynamische Funktionen

## 1. Statische Funktionen:

Statische Inhalte sind fest und ändern sich nicht dynamisch basierend auf Benutzereingaben. Sie können direkt in HTML oder mit serverseitigem Rendering generiert werden, aber sie sind weitgehend unabhängig von benutzerseitigen Aktionen.

**Beispiele für statische Funktionen:**

- Über uns / Kontakt / Impressum-Seiten: Diese Seiten enthalten Informationen, die sich selten ändern. Diese Seiten können in reinem HTML erstellt werden und erfordern keine dynamische Server-Interaktion.
- AGB und Datenschutzseiten: Dies sind ebenfalls Inhalte, die regelmäßig aktualisiert werden, aber nur durch die Firma selbst. Auch diese können statisch bleiben.
- Navigationselemente und das Layout der Webseite: Das Grundgerüst der Webseite, wie Header, Footer, Navigation, etc., kann als statischer Inhalt beibehalten werden.

**Technologien:**

- HTML/CSS: Für die statische Struktur und das Layout.
- Minimaler Einsatz von JavaScript: Für interaktive, aber statische Elemente (z.B. Dropdown-Menüs ohne serverseitige Abfragen).

---

## 2. Dynamische Funktionen:

Dynamische Funktionen ändern sich basierend auf Benutzereingaben oder anderen externen Faktoren (wie z.B. einer Datenbank). Diese erfordern entweder clientseitige oder serverseitige Verarbeitung.

**Beispiele für dynamische Funktionen:**

- Benutzerverwaltung (Login/Logout): Die Hotels müssen sich einloggen, um ihre Buchungen zu verwalten. Das Login-System sollte auf einer Datenbank basieren, die die Benutzer authentifiziert.
- Buchungssystem: Das zentrale Feature der Seite ist dynamisch. Es muss in der Lage sein, Daten von den Benutzern (Hotels) zu erfassen, diese zu verarbeiten und entweder in einer Datenbank zu speichern oder für die weitere Verarbeitung verfügbar zu machen.
- Verfügbarkeitsprüfung: Es wäre sinnvoll, die Verfügbarkeit von eBikes in Echtzeit zu prüfen. Dies könnte durch dynamische Abfragen in einer Datenbank erfolgen, um sicherzustellen, dass eBikes nicht überbucht werden.

**Technologien:**

- Serverseitige Skriptsprachen (PHP, Python, Node.js): Um Daten zu verarbeiten, z.B. bei der Registrierung, dem Login oder der Buchung von eBikes.
- Datenbanken (MySQL, PostgreSQL): Zum Speichern von Hotelinformationen, Buchungen und eBike-Verfügbarkeiten.
- Clientseitige Technologien (JavaScript, AJAX): Für Echtzeit-Interaktionen wie die Überprüfung der Verfügbarkeit von eBikes, ohne die Seite neu zu laden. AJAX kann verwendet werden, um Daten von der Datenbank zu holen, ohne die Seite komplett zu aktualisieren.
- RESTful API: Falls du eine Schnittstelle erstellen möchtest, die auch andere Anwendungen nutzen können (z.B. für mobile Apps), könnte eine API sinnvoll sein.

---

### Empfehlungen für dynamische vs. statische Bereiche:

| **Funktion**                     | **Statisch** | **Dynamisch** | **Technologien**                      |
|-----------------------------------|--------------|---------------|---------------------------------------|
| **Login/Logout**                  |              | ✓             | PHP (Server-seitig) + MySQL           |
| **Buchungsformular**              |              | ✓             | PHP, MySQL, JavaScript, AJAX          |
| **Benutzerprofilseite**           |              | ✓             | PHP, MySQL                            |
| **Buchungsbestätigung**           |              | ✓             | PHP                                   |
| **Seiten wie Impressum/AGB**      | ✓            |               | HTML/CSS                              |
| **Navigation (Header/Footer)**    | ✓            |               | HTML/CSS                              |
| **Verfügbarkeitsprüfung**         |              | ✓             | PHP, JavaScript, AJAX, MySQL          |
| **Kontaktdaten / Über uns**       | ✓            |               | HTML/CSS                              |

---

## Empfehlung zu den verwendeten Technologien:

1. **HTML/CSS:**
    - Zur Darstellung und Strukturierung der statischen Inhalte und des grundlegenden Layouts der Seite.

2. **PHP (Server-seitig):**
    - Für alle dynamischen Funktionen wie die Verarbeitung von Formularen, Benutzeranmeldung und Buchungslogik. PHP ist weit verbreitet und besonders nützlich in Kombination mit MySQL für Webanwendungen.

3. **JavaScript (Client-seitig):**
    - Um eine reaktive, benutzerfreundliche Oberfläche zu schaffen. JavaScript kann dafür sorgen, dass Teile der Seite dynamisch aktualisiert werden, ohne die gesamte Seite neu zu laden (z.B. mit AJAX für Verfügbarkeitsprüfungen).

4. **MySQL (Datenbank):**
    - Um Informationen über Hotels, Buchungen und eBike-Verfügbarkeiten zu speichern. MySQL lässt sich gut mit PHP kombinieren und ist leicht skalierbar.

5. **AJAX:**
    - Zur Echtzeit-Überprüfung von Buchungsinformationen (z.B. Verfügbarkeit von eBikes), ohne dass die Seite komplett neu geladen wird. Dies sorgt für eine bessere Nutzererfahrung.

6. **RESTful API (optional):**
    - Wenn die Buchungsplattform in Zukunft auch über mobile Apps oder andere Drittanbieter-Systeme zugänglich sein soll, könnte eine API sinnvoll sein.

---

## Zusammenfassung:

- Statische Inhalte können direkt mit **HTML und CSS** erstellt werden, da sie sich selten ändern und keine dynamischen Daten benötigen.
- Dynamische Funktionen wie die Buchung, Benutzeranmeldung und Verfügbarkeitsprüfungen sollten **serverseitig mit PHP** und **clientseitig mit JavaScript** (insbesondere AJAX) umgesetzt werden, um eine reibungslose Interaktion zu gewährleisten.
- **MySQL** sollte als Datenbank dienen, um Benutzer- und Buchungsdaten zu speichern.
- Eine **RESTful API** kann für zukünftige Erweiterungen (z.B. mobile Apps) hilfreich sein.